### Empty output block

Example Markdown file with an empty output fenced code block.

Code block

```python
print('Hello World- this is a non-empty code block')
```

Expected output has no text-

```
```